#!/bin/sh

# Copyright (c) 2009-2010 Hewlett-Packard Development Company, L.P. <dannf@hp.com>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#     * Redistributions of source code must retain the above
#       copyright notice, this list of conditions and the following
#       disclaimer.
#
#     * Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials
#       provided with the distribution.
#
#     * Neither the name of the Hewlett-Packard Co. nor the names
#       of its contributors may be used to endorse or promote
#       products derived from this software without specific prior
#       written permission.
#
# THIS SOFTWARE IS PROVIDED BY HEWLETT-PACKARD DEVELOPMENT COMPANY
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# HEWLETT-PACKARD DEVELOPMENT COMPANY BE LIABLE FOR ANY DIRECT,
# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#

DISTROID_VERSION=1.8.1

#ROOT=./

# ---- Red Hat ----

is_redhat() {
    if ( [ ! -f "$ROOT/etc/mrg-release" ] && \
         [ ! -f "$ROOT/etc/redhat-release" ] ||
         [ -f "$ROOT/etc/enterprise-release" ] ||
         [ -f "$ROOT/etc/oracle-release" ] ); then
	return 1
    fi
    
    if [ -f "$ROOT/etc/mrg-release" ] ; then
        if grep -q '^Red Hat' "$ROOT/etc/mrg-release"; then
	    return 0
        fi
    elif [ -f "$ROOT/etc/redhat-release" ] ; then
        if grep -q '^Red Hat' "$ROOT/etc/redhat-release"; then
	    return 0
        fi
    fi

    return 1
}

redhat_vendor() {
    echo "Red Hat"
}

redhat_name() {
    echo "Red Hat"
}

redhat_flavor() {
    if [ -f "$ROOT/etc/mrg-release" ] ; then
        if grep -q "MRG" "$ROOT/etc/mrg-release"; then
            echo "MRG"
            return 0
        fi
    elif grep -q "Advanced Server" "$ROOT/etc/redhat-release"; then
        echo "AS" && return 0
    elif grep -q "AS" "$ROOT/etc/redhat-release"; then
        echo "AS" && return 0
    elif grep -q "ES" "$ROOT/etc/redhat-release"; then
        echo "ES" && return 0
    elif grep -q "WS" "$ROOT/etc/redhat-release"; then
        echo "WS" && return 0
    elif grep -q "Client" "$ROOT/etc/redhat-release"; then
        echo "Client" && return 0
    elif grep -q "Desktop" "$ROOT/etc/redhat-release"; then
        echo "Desktop" && return 0
    elif grep -q "Server" "$ROOT/etc/redhat-release"; then
        echo "Server" && return 0
    elif grep -q "Workstation" "$ROOT/etc/redhat-release"; then
        echo "Workstation" && return 0
    elif grep -q "Enterprise Linux" "$ROOT/etc/redhat-release"; then
        echo "Enterprise Linux" && return 0
    fi
}

redhat_major() {

    local flavor="$(redhat_flavor)"
    if [ "$flavor" = "MRG" ] ; then
	local major=$(sed -r 's/^Red Hat Enterprise MRG ([0-9]+).*/\1/' < "$ROOT/etc/mrg-release")
        echo ${major}
        return 0
    fi

    if grep -q -e Pensacola -e Panama -e Tampa "$ROOT/etc/redhat-release"; then
	echo 2  && return 0
    elif grep -q Taroon "$ROOT/etc/redhat-release"; then
	echo 3 && return 0
    elif grep -q Nahant "$ROOT/etc/redhat-release"; then
	echo 4 && return 0
    elif grep -q Tikanga "$ROOT/etc/redhat-release"; then
	echo 5 && return 0
    elif grep -q Santiago "$ROOT/etc/redhat-release"; then
	echo 6 && return 0
    elif grep -q Maipo "$ROOT/etc/redhat-release"; then
	echo 7 && return 0
    fi

}

redhat_version() {
    local flavor="$(redhat_flavor)"
    if [ "$flavor" = "MRG" ] ; then
	local version=$(sed -r 's/^Red Hat Enterprise MRG ([0-9]+(\.[0-9]+)).*/\1/' < "$ROOT/etc/mrg-release")
        echo ${version} && return 0
    fi

    local major="$(redhat_major)"
    if [ "$major" -eq 2 ] ; then
	local version=$(sed -r 's/^Red Hat.*release ([0-9]+(\.[0-9]+)).*/\1/' < "$ROOT/etc/redhat-release")
	echo ${version} && return 0
    elif ( [ "$major" -eq 3 ] || [ "$major" -eq 4 ] ) ; then
        if grep -q "Update" "$ROOT/etc/redhat-release" ; then
	    local minor=$(sed -r 's/^Red Hat Enterprise Linux.*Update ([0-9]+).*/\1/' < "$ROOT/etc/redhat-release")
	    if echo $minor | grep -q ^[0-9] ; then
                echo ${major}.${minor} && return 0
            fi
        else
            echo ${major}.0 && return 0
        fi
    elif ( [ "$major" -eq 5 ] || [ "$major" -eq 6 ] || [ "$major" -eq 7 ] ) ; then
	local version=$(sed -r 's/^Red Hat Enterprise Linux.*release ([0-9]+(\.[0-9])*).*/\1/' < "$ROOT/etc/redhat-release")
	echo ${version} && return 0
    fi

}

redhat_description() {
    if [ -f "$ROOT/etc/mrg-release" ]; then
        cat "$ROOT/etc/mrg-release"
        return 0
    else
        cat "$ROOT/etc/redhat-release"
    fi
}

redhat_uid() {
    local name="RHEL"
    local version="$(redhat_version)"
    local flavor="$(redhat_flavor)"
    echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

# ---- Oracle ----

is_oracle() {
    if ( [ ! -f "$ROOT/etc/enterprise-release" ] &&
         [ ! -f "$ROOT/etc/oracle-release" ] ) ; then
	return 1
    elif [ -f "$ROOT/etc/enterprise-release" ] ; then
        grep -q '^Enterprise' "$ROOT/etc/enterprise-release" && return 0
    elif [ -f "$ROOT/etc/oracle-release" ] ; then
        grep -q '^Oracle' "$ROOT/etc/oracle-release" && return 0
    fi
}

oracle_vendor() {
    echo "Oracle"
}

oracle_name() {
    echo "Oracle Linux"
}

oracle_flavor() {
    if [ -f "$ROOT/etc/enterprise-release" ] ; then
        grep -q "Server" "$ROOT/etc/enterprise-release" &&
        echo "Server" && return 0
    elif [ -f "$ROOT/etc/oracle-release" ] ; then
        grep -q "Server" "$ROOT/etc/oracle-release" &&
        echo "Server" && return 0
    fi
}

oracle_major() {

    if [ -f "$ROOT/etc/enterprise-release" ] ; then
        grep -q Carthage "$ROOT/etc/enterprise-release" &&
	echo 5 && return 0
    elif [ -f "$ROOT/etc/oracle-release" ] ; then
        local major=$(sed -r 's/^Oracle Linux Server release ([0-9]+).*/\1/' < "$ROOT/etc/oracle-release")
        echo ${major} && return 0
    fi

}

oracle_version() {
    local major="$(oracle_major)"
    if ( [ "$major" -eq 6 ] ) ; then
        local version=$(sed -r 's/^Oracle Linux Server release ([0-9]+(\.[0-9]+)).*/\1/' < "$ROOT/etc/oracle-release")
        echo ${version} && return 0

    elif ( [ "$major" -eq 5 ] ) ; then
	local version=$(sed -r 's/^Enterprise Linux.*release ([0-9]+(\.[0-9])*).*/\1/' < "$ROOT/etc/enterprise-release")
	echo ${version} && return 0
    fi

}

oracle_description() {
    if [ -f "$ROOT/etc/enterprise-release" ]; then
        cat "$ROOT/etc/enterprise-release"
    elif [ -f "$ROOT/etc/oracle-release" ]; then
        cat "$ROOT/etc/oracle-release"
    fi
}

oracle_uid() {
    local name="$(oracle_name)"
    local version="$(oracle_version)"
    local flavor="$(oracle_flavor)"
    echo "${name}-${version}${flavor}" | tr -d [:blank:]
}


# ---- Debian ----

is_debian() {
    if [ ! -f "$ROOT/etc/debian_version" ]; then
        return 1
    fi
    if is_ubuntu; then
        return 2
    fi
    if [ -f "$ROOT/etc/os-release" ]; then
        if grep -q Debian "$ROOT/etc/os-release" ] ; then
            return 0
        fi
    fi
}

debian_vendor() {
    echo "Debian"
}

debian_name() {
    echo "Debian GNU/Linux"
}

debian_flavor() {
    echo ""
}

debian_major() {
    # Debian uses a x(.y sometimes) major
    if [ -f "$ROOT/etc/os-release" ]; then
        grep ^VERSION_ID "$ROOT/etc/os-release" | cut -d'"' -f2
    else
        if grep -E -q '^[0-9]+\.[0-9]+\.*' "$ROOT/etc/debian_version"; then
	    sed -r 's/^([0-9]+\.[0-9]+)\..*$/\1/' < "$ROOT/etc/debian_version"
        fi
    fi
}

debian_version() {
    # In testing/sid, /etc/debian_version contains codenames.
    # Check that we have a valid major number first so to avoid
    # emitting output for those releases.
    if [ -n "$(debian_major)" ]; then
	cat "$ROOT/etc/debian_version"
    fi
}

debian_description() {
    echo "Debian GNU/Linux $(cat $ROOT/etc/debian_version)"
}

debian_uid() {
    #local distro="deb"
    #local version="$(debian_version)"
    #if [ -n "$version" ]; then
	#echo "${distro}${version}"
    #fi
    #local name="$(debian_name)"
    local name="Debian"
    local version="$(debian_version)"
    local flavor="$(debian_flavor)"
    echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

is_suse() {
    if [ ! -f "$ROOT/etc/SuSE-release" ]; then
	return 1
    fi

    if grep -q '^SUSE Linux' "$ROOT/etc/SuSE-release"; then
	return 0
    fi

    return 1
}

suse_vendor() {
    echo "SUSE"
}

suse_name() {
    echo "SUSE"
}

suse_flavor() {
    if grep -q "Enterprise Server" "$ROOT/etc/SuSE-release"; then
	echo "S"
    elif grep -q "Enterprise Desktop" "$ROOT/etc/SuSE-release"; then
	echo "D"
    fi
}

suse_major() {
    grep ^VERSION "$ROOT/etc/SuSE-release" | sed -r 's/^VERSION = ([0-9]+)$/\1/'
}

suse_version() {
    local major="$(suse_major)"
    local patchlevel="$(grep ^PATCHLEVEL $ROOT/etc/SuSE-release | \
                        sed -r 's/^PATCHLEVEL = ([0-9]+)$/\1/')"

    if [ "$patchlevel" -eq 0 ]; then
	echo "$major"
    else
	echo "${major}SP${patchlevel}"
    fi
}

suse_description() {
    head -1 "$ROOT/etc/SuSE-release" | sed 's/ (.*)$//'
}

suse_uid() {
    local name="SLE"
    local version="$(suse_version)"
    local flavor="$(suse_flavor)"
    echo "${name}${flavor}-${version}" | tr -d [:blank:]
}

is_opensuse() {
    if [ ! -f "$ROOT/etc/SuSE-release" ]; then
	return 1
    fi

    if grep -q ^openSUSE "$ROOT/etc/SuSE-release"; then
	return 0
    fi

    if [ -f "$ROOT/etc/os-release" ]; then
        if grep -q ^NAME=openSUSE "$ROOT/etc/os-release"; then
	    return 0
        fi
    fi

    return 1
}

opensuse_vendor() {
    echo "openSUSE"
}

opensuse_name() {
    echo "openSUSE"
}

opensuse_flavor() {
    return
}

opensuse_major() {
    if [ -f "$ROOT/etc/os-release" ]; then
        grep ^VERSION_ID $ROOT/etc/os-release | sed -r 's/^VERSION_ID="([0-9]+)(\.[0-9]+)"*$/\1/'
    else
        grep ^VERSION "$ROOT/etc/SuSE-release" | sed -r 's/^VERSION = ([0-9]+)(\.[0-9]+)*$/\1/'
    fi

}

opensuse_version() {
    if [ -f "$ROOT/etc/os-release" ]; then
        grep ^VERSION_ID "$ROOT/etc/os-release" | sed -r 's/^VERSION_ID="([0-9]+(\.[0-9]+)*)"$/\1/'
    else
        grep ^VERSION "$ROOT/etc/SuSE-release" | sed -r 's/^VERSION = ([0-9]+(\.[0-9]+)*)$/\1/'
    fi
}

opensuse_description() {
    if [ -f "$ROOT/etc/os-release" ]; then
        grep ^PRETTY_NAME $ROOT/etc/os-release | cut -d\" -f2 | cut -d" " -f1-2
    else
        head -1 "$ROOT/etc/SuSE-release" | sed 's/ (.*)$//'
    fi
}

opensuse_uid() {
    local name="$(opensuse_name)"
    local version="$(opensuse_version)"
    local flavor="$(opensuse_flavor)"
    echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

is_ubuntu() {
    if [ -f "$ROOT/etc/lsb-release" ] && \
	grep -q '^DISTRIB_ID=Ubuntu' "$ROOT/etc/lsb-release"; then
	return 0
    else
	return 1
    fi
}

ubuntu_vendor() {
    echo "Ubuntu"
}

ubuntu_name() {
    echo "Ubuntu"
}

ubuntu_flavor() {
    echo ""
}

ubuntu_major() {
    grep ^DISTRIB_RELEASE "$ROOT/etc/lsb-release" | \
	sed -r 's/^DISTRIB_RELEASE=(.*)$/\1/'
}

ubuntu_version() {
    ubuntu_major
}

ubuntu_description() {
    grep ^DISTRIB_DESCRIPTION "$ROOT/etc/lsb-release" | \
	sed -r 's/^DISTRIB_DESCRIPTION="(.*)"$/\1/'g
}

ubuntu_uid() {
    local name="$(ubuntu_name)"
    local version="$(ubuntu_version)"
    local flavor="$(ubuntu_flavor)"
    echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

is_vmwesx() {
    if [ -f "$ROOT/etc/vmware-release" ] && \
	[ -x "$ROOT/usr/bin/vmware" ]; then
	return 0
    else
	return 1
    fi
}

vmwesx_vendor() {
    echo "VMware"
}

vmwesx_name() {
    echo "VMware ESX"
}

vmwesx_flavor() {
    local s="$($ROOT/usr/bin/vmware -v | head -1)"
    local flavor=""

    if echo "$s" | grep -E -q '^VMware ESX (.*) ([0-9]+)(\.[0-9]+)* build-[0-9]+$'; then
	flavor="$(echo $s | sed -r 's/^VMware ESX (.*) ([0-9]+)(\.[0-9]+)* build-[0-9]+$/\1/')"
    fi

    echo "$flavor"
}

vmwesx_major() {
    local maj=""

    if vmwesx_version | grep -E -q '^([0-9]+)(\.[0-9]+)*$'; then
	maj=$(vmwesx_version | sed -r 's/^([0-9]+)(\.[0-9]+)*$/\1/')
    fi
    echo "$maj"
}

vmwesx_version() {
    local s="$($ROOT/usr/bin/vmware -v | head -1)"
    local ver=""

    if echo "$s" | grep -E -q '^VMware ESX(.*) ([0-9]+)(\.[0-9]+)* build-[0-9]+$'; then
	ver="$(echo $s | sed -r 's/^VMware ESX(.*) (([0-9]+)(\.[0-9]+)*) build-[0-9]+$/\2/')"
    fi

    echo "$ver"
}

vmwesx_description() {
    "$ROOT/usr/bin/vmware" -v
}

vmwesx_uid() {
    echo "vmwesx$(vmwesx_version)"
    #local name="$(redhat_name)"
    #local version="$(redhat_version)"
    #local flavor="$(redhat_flavor)"
    #echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

is_ax() {
    if [ -f "$ROOT/etc/asianux-release" ]; then
	return 0
    else
	return 1
    fi
}

ax_vendor() {
    echo "Asianux"
}

ax_name() {
    echo "Asianux"
}

ax_flavor() {
    local flavor=""

    if grep -E -q '^Asianux (.*) (([0-9]+)(\.[0-9]+)*) (\([a-zA-Z ]+( SP([0-9]+))?\))$' "$ROOT/etc/asianux-release"; then
	flavor="$(sed -r 's/^Asianux (.*) (([0-9]+)(\.[0-9]+)*) (\([a-zA-Z ]+( SP([0-9]+))?\))$/\1/' < $ROOT/etc/asianux-release)"
    fi

    echo "$flavor"
}

ax_major() {
    if grep -q Quartet  "$ROOT/etc/asianux-release"; then
	echo 3  && return 0
    elif grep -q Hiranya "$ROOT/etc/asianux-release"; then
	echo 4 && return 0
    fi
}

ax_version() {
    local ver=""
    local spver=""

    if grep -E -q '^Asianux (.*) (([0-9]+)(\.[0-9]+)*) (\([a-zA-Z ]+( SP([0-9]+))?\))$' "$ROOT/etc/asianux-release"; then
	ver="$(sed -r 's/^Asianux (.*) (([0-9]+)(\.[0-9]+)*) (\([a-zA-Z ]+( SP([0-9]+))?\))$/\2/' < $ROOT/etc/asianux-release)"
	spver="$(sed -r 's/^Asianux (.*) (([0-9]+)(\.[0-9]+)*) (\([a-zA-Z ]+( SP([0-9]+))?\))$/\7/' < $ROOT/etc/asianux-release)"
    fi

    if [ -n "$spver" ]; then
	ver="${ver}.${spver}"
    fi

    echo "$ver"
}

ax_description() {
    cat $ROOT/etc/asianux-release
}

ax_uid() {
    local name="$(ax_name)"
    local version="$(ax_version)"
    local flavor="$(ax_flavor)"
    echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

is_centos() {
    if [ ! -f "$ROOT/etc/redhat-release" ]; then
	return 1
    fi
    
    if grep -q '^CentOS' "$ROOT/etc/redhat-release"; then
	return 0
    fi

    return 1
}

centos_vendor() {
    echo "CentOS"
}

centos_name() {
    echo "CentOS"
}

centos_flavor() {
    return
}

centos_version() {
    local version=""
    if grep -Eq '^CentOS release ([0-9]+(\.[0-9]+)*) \(.*\)$' "$ROOT/etc/redhat-release"; then
	version="$(sed -r 's/^CentOS release ([0-9]+(\.[0-9]+)*) \(.*\)$/\1/' < $ROOT/etc/redhat-release)"
    fi
    echo "$version"
}

centos_major() {
    local major=""
    if grep -Eq '^CentOS release ([0-9]+)(\.[0-9]+)* \(.*\)$' "$ROOT/etc/redhat-release"; then
	major="$(sed -r 's/^CentOS release ([0-9]+)(\.[0-9]+)* \(.*\)$/\1/' < $ROOT/etc/redhat-release)"
    fi
    echo "$major"
}

centos_description() {
    cat "$ROOT/etc/redhat-release"
}

centos_uid() {
    local name="$(centos_name)"
    local version="$(centos_version)"
    local flavor="$(centos_flavor)"
    echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

is_fedora() {
    if [ ! -f "$ROOT/etc/fedora-release" ]; then
	return 1
    fi
    
    if grep -q '^Fedora' "$ROOT/etc/fedora-release"; then
	return 0
    fi

    return 1
}

fedora_vendor() {
    echo "Fedora"
}

fedora_name() {
    echo "Fedora"
}

fedora_flavor() {
    return
}

fedora_version() {
    local version=""
    if grep -Eq '^Fedora release ([0-9]+(\.[0-9]+)*) \(.*\)$' "$ROOT/etc/fedora-release"; then
	version="$(sed -r 's/^Fedora release ([0-9]+(\.[0-9]+)*) \(.*\)$/\1/' < $ROOT/etc/fedora-release)"
    fi
    echo "$version"
}

fedora_major() {
    local major=""
    if grep -Eq '^Fedora release ([0-9]+)(\.[0-9]+)* \(.*\)$' "$ROOT/etc/fedora-release"; then
	major="$(sed -r 's/^Fedora release ([0-9]+)(\.[0-9]+)* \(.*\)$/\1/' < $ROOT/etc/fedora-release)"
    fi
    echo "$major"
}

fedora_description() {
    cat "$ROOT/etc/fedora-release"
}

fedora_uid() {
    local name="$(fedora_name)"
    local version="$(fedora_version)"
    local flavor="$(fedora_flavor)"
    echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

is_xenserver() {
    if [ ! -f "$ROOT/etc/redhat-release" ]; then
	return 1
    fi
    
    if grep -q '^XenServer' "$ROOT/etc/redhat-release"; then
	return 0
    fi

    return 1
}

xenserver_vendor() {
    echo "Citrix"
}

xenserver_name() {
    echo "XenServer"
}

xenserver_flavor() {
    return
}

xenserver_version() {
    local version=""
    if grep -Eq '^XenServer release (.*) \(.*\)$' "$ROOT/etc/redhat-release"; then
	version="$(sed -r 's/^XenServer release (.*) \(.*\)$/\1/' < $ROOT/etc/redhat-release)"
    fi
    echo "$version"
}

xenserver_major() {
    local major=""
    if grep -Eq '^XenServer release ([0-9]+)(\..*) \(.*\)$' "$ROOT/etc/redhat-release"; then
	major="$(sed -r 's/^XenServer release ([0-9]+)(\..*) \(.*\)$/\1/' < $ROOT/etc/redhat-release)"
    fi
    echo "$major"
}

xenserver_description() {
    cat "$ROOT/etc/redhat-release"
}

xenserver_uid() {
    echo "xenserver$(xenserver_version)"
    #local name="$(redhat_name)"
    #local version="$(redhat_version)"
    #local flavor="$(redhat_flavor)"
    #echo "${name}-${version}${flavor}" | tr -d [:blank:]
}

## boilerplate for adding new distros
## cut & paste, then search & replace "name" with a distro

## This function is for internal use only. It returns 0 if the distribution
## is of class "name", non-zero otherwise
# is_name() {
# }

## This function outputs a string representing the vendor. This should
## be a company/organization name - e.g. "Red Hat", "SUSE"
# name_vendor() {
# }

## This function outputs a string representing the distribution name.
## It should not distinguist between flavors.
## Good: "Red Hat", "SUSE Linux", "Debian GNU/Linux"
## Bad: "Red Hat Enterprise Linux", "SLES", "Debian"
# name_name() {
# }

## This function outputs a string that describes a specific flavor of
## the distribution - e.g., "Enterprise Server" or "Advanced Workstation"
# name_flavor() {
# }

## This function outputs a string that represents the major version of
## the distribution. For example, on RHEL 4.8 it would output "4", on
## Debian 5.0.3 it would output "5.0".
# name_major() {
# }

## This function outputs a string that represents the complete version
## of a distribution.
# name_version() {
# }

## This function outputs a single line of text that is used to describe
## the distribution. This is freeform text that may include codenames/etc.
## This is meant to be a pretty name exposed to users in management tools,
## not something that should be parsed.
# name_description() {
# }

## This should output a short string consisting of no whitespace that uniquely
## identifies this distro/flavor/version. The basically exists to create
## short tokens to be used in scripting/filenames.
# name_uid() {
# }

class=""

format=''
prefix=''
for opt ; do
    case $opt in
        --sh=*)
              format='sh'
              prefix=`echo $1 | cut -b 6- -`;
              shift
              ;;
        --sh)
              format='sh'
              prefix=''
              shift
              ;;
        --csh=*)
              format='csh'
              prefix=`echo $1 | cut -b 7- -`;
              shift
              ;;
        --csh)
              format='csh'
              prefix=''
              shift
              ;;
    esac
done

for c in redhat oracle debian suse ubuntu vmwesx ax centos fedora opensuse xenserver; do
    if is_${c}; then
	class="${c}"
    fi
done

if [ -z "${class}" ]; then
    echo "Error: Could not identify distribution" >&2
    exit 1
fi

for field in vendor name flavor major version description uid; do
    case $format in
        sh) echo "${prefix}${field}=\"$(${class}_${field})\"" ;;
        csh) echo "set ${prefix}${field}=\"$(${class}_${field})\"" ;;
        *)  echo "$field: $(${class}_${field})" ;;
    esac
done
