#!/usr/bin/python

#
# Copyright (c) 2009-2010 Hewlett-Packard Development Company, L.P. <dannf@hp.com>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#     * Redistributions of source code must retain the above
#       copyright notice, this list of conditions and the following
#       disclaimer.
#
#     * Redistributions in binary form must reproduce the above
#       copyright notice, this list of conditions and the following
#       disclaimer in the documentation and/or other materials
#       provided with the distribution.
#
#     * Neither the name of the Hewlett-Packard Co. nor the names
#       of its contributors may be used to endorse or promote
#       products derived from this software without specific prior
#       written permission.
#
# THIS SOFTWARE IS PROVIDED BY HEWLETT-PACKARD DEVELOPMENT COMPANY
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# HEWLETT-PACKARD DEVELOPMENT COMPANY BE LIABLE FOR ANY DIRECT,
# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#

import unittest
import subprocess
import os
import sys
#import os.path
import re

class DistroIdCase(unittest.TestCase):
    # Take the output of distro-id.sh and turn it into a dictionary
    def parseOutput(self, output):
        D = {}
        keyvalpair = re.compile('^(?P<key>.*):\s(?P<value>.*)$')
        lines = output.split('\n')
        for l in lines:
            m = keyvalpair.match(l)
            if m:
                D[m.group('key')] = m.group('value')
        return D

    def getCached(self, name):
        #cacheFile = os.path.join(os.getcwd(), 'samples', name, 'expected')
        cacheFile = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'samples', name, 'expected')
        f = open(cacheFile, 'r')
        data = f.read()
        f.close()
        return self.parseOutput(data)
        
    def collectAndCompare(self, name):
        cached = self.getCached(name)

        env = os.environ
        #env['ROOT'] = os.path.join(os.getcwd(), 'samples', name)
        env['ROOT'] = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'samples', name)
        #sp = subprocess.Popen(os.path.join(os.getcwd(), 'distro-id.sh'),
        sp = subprocess.Popen(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'distro-id.sh'),
                              stdout = subprocess.PIPE,
                              env = env)
        (stdout, stdin) = sp.communicate()
        new = self.parseOutput(stdout)

        for key in cached.keys():
            if cached[key] != new[key]:
                return False
        return True

# catalog of all known distro/version, but
# test only those currently supported by distribution

    def testAsianuxServer3(self):
        self.failUnless(self.collectAndCompare('Asianux3'))

    def testAsianuxServer3SP1(self):
        self.failUnless(self.collectAndCompare('Asianux3SP1'))

    def testAsianuxServer3SP1(self):
        self.failUnless(self.collectAndCompare('Asianux3SP2'))

    def testAsianuxServer3SP1(self):
        self.failUnless(self.collectAndCompare('Asianux3SP3'))

    def testAsianuxServer3SP1(self):
        self.failUnless(self.collectAndCompare('Asianux3SP4'))

    def testAsianuxServer4(self):
        self.failUnless(self.collectAndCompare('Asianux4'))

    def testAsianuxServer4SP1(self):
        self.failUnless(self.collectAndCompare('Asianux4SP1'))

    def testRedHat1_3MRG(self):
        self.failUnless(self.collectAndCompare('RedHat1.3MRG'))

    def testRedHat2_0MRG(self):
        self.failUnless(self.collectAndCompare('RedHat2.0MRG'))

    def testRedHat2_1AS(self):
        self.failUnless(self.collectAndCompare('RedHat2.1AS'))

    def testRedHat2_1ES(self):
        self.failUnless(self.collectAndCompare('RedHat2.1ES'))

    def testRedHat2_1WS(self):
        self.failUnless(self.collectAndCompare('RedHat2.1WS'))

    def testRedHat3_0AS(self):
        self.failUnless(self.collectAndCompare('RedHat3.0AS'))

    def testRedHat3_1AS(self):
        self.failUnless(self.collectAndCompare('RedHat3.1AS'))

    def testRedHat4_0AS(self):
        self.failUnless(self.collectAndCompare('RedHat4.0AS'))

    def testRedHat4_1AS(self):
        self.failUnless(self.collectAndCompare('RedHat4.1AS'))

    def testRedHat5_0Client(self):
        self.failUnless(self.collectAndCompare('RedHat5.0Client'))

    def testRedHat5_0Server(self):
        self.failUnless(self.collectAndCompare('RedHat5.0Server'))

    def testRedHat5_1Client(self):
        self.failUnless(self.collectAndCompare('RedHat5.1Client'))

    def testRedHat5_1Server(self):
        self.failUnless(self.collectAndCompare('RedHat5.1Server'))

    def testRedHat6_0Server(self):
        self.failUnless(self.collectAndCompare('RedHat6.0Server'))

    def testRedHat6_1Server(self):
        self.failUnless(self.collectAndCompare('RedHat6.1Server'))

    def testRedHat7_0Server(self):
        self.failUnless(self.collectAndCompare('RedHat7.0Server'))

    def testOracle5_0Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.0Server'))

    def testOracle5_1Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.1Server'))

    def testOracle5_2Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.2Server'))

    def testOracle5_3Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.3Server'))

    def testOracle5_4Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.4Server'))

    def testOracle5_5Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.5Server'))

    def testOracle5_6Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.6Server'))

    def testOracle5_7Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.7Server'))

    def testOracle5_8Server(self):
        self.failUnless(self.collectAndCompare('Oracle5.8Server'))

    def testOracle6_0Server(self):
        self.failUnless(self.collectAndCompare('Oracle6.0Server'))

    def testOracle6_1Server(self):
        self.failUnless(self.collectAndCompare('Oracle6.1Server'))

    def testOracle6_2Server(self):
        self.failUnless(self.collectAndCompare('Oracle6.2Server'))

    def testOracle6_3Server(self):
        self.failUnless(self.collectAndCompare('Oracle6.3Server'))

    #def testSLED10SP3(self):
        #self.failUnless(self.collectAndCompare('SLED10SP3'))

    def testSLED10SP4(self):
        self.failUnless(self.collectAndCompare('SLED10SP4'))

    #def testSLED11(self):
        #self.failUnless(self.collectAndCompare('SLED11'))

    #def testSLED11SP1(self):
        #self.failUnless(self.collectAndCompare('SLED11SP1'))

    def testSLED11SP2(self):
        self.failUnless(self.collectAndCompare('SLED11SP2'))

    def testSLED11SP3(self):
        self.failUnless(self.collectAndCompare('SLED11SP3'))

    #def testSLES10SP3(self):
        #self.failUnless(self.collectAndCompare('SLES10SP3'))

    def testSLES10SP4(self):
        self.failUnless(self.collectAndCompare('SLES10SP4'))

    #def testSLES11(self):
        #self.failUnless(self.collectAndCompare('SLES11'))

    #def testSLES11SP1(self):
        #self.failUnless(self.collectAndCompare('SLES11SP1'))

    def testSLES11SP2(self):
        self.failUnless(self.collectAndCompare('SLES11SP2'))

    def testSLES11SP3(self):
        self.failUnless(self.collectAndCompare('SLES11SP3'))

    #def testDebian502(self):
        #self.failUnless(self.collectAndCompare('deb5.0.2'))

    #def testDebian608(self):
        #self.failUnless(self.collectAndCompare('deb6.0.8'))

    def testDebian73(self):
        self.failUnless(self.collectAndCompare('deb7.3'))

    #def testUbuntu904(self):
        #self.failUnless(self.collectAndCompare('ubuntu9.04'))

    #def testUbuntu910(self):
        #self.failUnless(self.collectAndCompare('ubuntu9.10'))

    def testUbuntu1004(self):
        self.failUnless(self.collectAndCompare('ubuntu10.04'))

    #def testUbuntu1010(self):
        #self.failUnless(self.collectAndCompare('ubuntu10.10'))

    #def testUbuntu1104(self):
        #self.failUnless(self.collectAndCompare('ubuntu11.04'))

    def testUbuntu1110(self):
        self.failUnless(self.collectAndCompare('ubuntu11.10'))

    def testUbuntu1204(self):
        self.failUnless(self.collectAndCompare('ubuntu12.04'))

    def testUbuntu1210(self):
        self.failUnless(self.collectAndCompare('ubuntu12.10'))

    def testUbuntu1304(self):
        self.failUnless(self.collectAndCompare('ubuntu13.04'))

    def testUbuntu1310(self):
        self.failUnless(self.collectAndCompare('ubuntu13.10'))

    def testVMwareESX350(self):
        self.failUnless(self.collectAndCompare('vmwesx3.5.0'))

    def testVMwareESX400(self):
        self.failUnless(self.collectAndCompare('vmwesx4.0.0'))

    #def testCentOS50(self):
        #self.failUnless(self.collectAndCompare('centos5.0'))

    #def testCentOS51(self):
        #self.failUnless(self.collectAndCompare('centos5.1'))

    #def testCentOS52(self):
        #self.failUnless(self.collectAndCompare('centos5.2'))

    #def testCentOS53(self):
        #self.failUnless(self.collectAndCompare('centos5.3'))

    #def testCentOS54(self):
        #self.failUnless(self.collectAndCompare('centos5.4'))

    #def testCentOS55(self):
        #self.failUnless(self.collectAndCompare('centos5.5'))

    #def testCentOS56(self):
        #self.failUnless(self.collectAndCompare('centos5.6'))

    #def testCentOS57(self):
        #self.failUnless(self.collectAndCompare('centos5.7'))

    #def testCentOS58(self):
        #self.failUnless(self.collectAndCompare('centos5.8'))

    #def testCentOS59(self):
        #self.failUnless(self.collectAndCompare('centos5.9'))

    def testCentOS510(self):
        self.failUnless(self.collectAndCompare('centos5.10'))

    #def testCentOS60(self):
        #self.failUnless(self.collectAndCompare('centos6.0'))

    #def testCentOS61(self):
        #self.failUnless(self.collectAndCompare('centos6.1'))

    #def testCentOS62(self):
        #self.failUnless(self.collectAndCompare('centos6.2'))

    #def testCentOS63(self):
        #self.failUnless(self.collectAndCompare('centos6.3'))

    #def testCentOS64(self):
        #self.failUnless(self.collectAndCompare('centos6.4'))

    def testCentOS65(self):
        self.failUnless(self.collectAndCompare('centos6.5'))

    #def testFedora10(self):
        #self.failUnless(self.collectAndCompare('fedora10'))

    #def testFedora11(self):
        #self.failUnless(self.collectAndCompare('fedora11'))

    #def testFedora12(self):
        #self.failUnless(self.collectAndCompare('fedora12'))

    #def testFedora13(self):
        #self.failUnless(self.collectAndCompare('fedora13'))

    #def testFedora14(self):
        #self.failUnless(self.collectAndCompare('fedora14'))

    #def testFedora15(self):
        #self.failUnless(self.collectAndCompare('fedora15'))

    #def testFedora16(self):
        #self.failUnless(self.collectAndCompare('fedora16'))

    #def testFedora17(self):
        #self.failUnless(self.collectAndCompare('fedora17'))

    def testFedora18(self):
        self.failUnless(self.collectAndCompare('fedora18'))

    def testFedora19(self):
        self.failUnless(self.collectAndCompare('fedora19'))

    def testFedora20(self):
        self.failUnless(self.collectAndCompare('fedora20'))

    #def testopenSUSE11_0(self):
        #self.failUnless(self.collectAndCompare('openSUSE11.0'))

    #def testopenSUSE11_1(self):
        #self.failUnless(self.collectAndCompare('openSUSE11.1'))

    #def testopenSUSE11_2(self):
        #self.failUnless(self.collectAndCompare('openSUSE11.2'))

    #def testopenSUSE11_3(self):
        #self.failUnless(self.collectAndCompare('openSUSE11.3'))

    def testopenSUSE11_4(self):
        self.failUnless(self.collectAndCompare('openSUSE11.4'))

    #def testopenSUSE12_1(self):
        #self.failUnless(self.collectAndCompare('openSUSE12.1'))

    def testopenSUSE12_2(self):
        self.failUnless(self.collectAndCompare('openSUSE12.2'))

    def testopenSUSE12_3(self):
        self.failUnless(self.collectAndCompare('openSUSE12.3'))

    def testopenSUSE13_1(self):
        self.failUnless(self.collectAndCompare('openSUSE13.1'))

    def testXenServer5(self):
        self.failUnless(self.collectAndCompare('xenserver5.6.0-30658p'))

if __name__ == '__main__':
    try:
        defaultTest = sys.argv[1]
    except:
        defaultTest = None
    unittest.main(defaultTest=defaultTest)
